iterationtools.iterate_pitched_tie_chains_in_expr
=================================================

.. autofunction:: abjad.tools.iterationtools.iterate_pitched_tie_chains_in_expr.iterate_pitched_tie_chains_in_expr
